#!/bin/sh
scriptdir=`dirname $0` ; cd ${scriptdir} ; scriptdir=`pwd` ; cd - > /dev/null

livedefault=false
partedbin=`sudo which parted`
bootlabel=BOOT
bootuuid=1234-5678

# max image size 1GB
maxSize=1073741824

liveSize=0
freeSize=0
partSize=0
needSize=0
usedSize=0
gaiusLdr=none
gaiusCDir=none
gaiusCfg=none.cfg
gaEfiLdr=none
gaEfiCDir=none
gaEfiCfg=none.cfg
gaSysLdr=none
gaSysCDir=none
gaSysCfg=none.cfg


mountimg() {
  echo "Extracting ip/$1.img.gz"
  gzip -cd ${workdir}/iso/ip/$1.img.gz > ${workdir}/$1.img

  ofs=0
  sze=0
  while read n b e s t f z ; do
    ofs=`echo $b | tr -d B`
    sze=`echo $s | tr -d B`
  done <<< $(LANG=C $partedbin ${workdir}/$1.img unit b print 2>/dev/null | grep -m1 fat)

  if [ $1 = gaius ]; then

    maxSzl=$sze

    imgSze=`stat -c %s ${workdir}/$1.img`
    imgSzl=`expr ${imgSze} - ${ofs}`
    if [ ${imgSzl} -gt ${maxSzl} ]; then
      maxSzl=${imgSzl}
    fi

    echo ofs: $ofs sze: $sze szl: ${maxSzl}

    LOOPDEV=`sudo losetup --find --show -o ${ofs} --sizelimit ${maxSzl} ${workdir}/$1.img`

    lbl=`sudo fatlabel $LOOPDEV | tail -1`
    uid=`sudo blkid $LOOPDEV -o export | grep -E '^UUID=' | cut -d '=' -f 2 | tr -d -`

    bootlabel=$lbl
    bootuuid=`sudo blkid $LOOPDEV -o export | grep -E '^UUID=' | cut -d '=' -f 2`

    echo ID: $uid label: $lbl

    sudo losetup -d $LOOPDEV
  fi

  sudo mount -o loop,offset=$ofs,sizelimit=$sze ${workdir}/$1.img ${workdir}/mount

  #if [ $1 = gaius ]; then
  #  resizeimg $1 ${maxSize}
  #fi
}

resizeimg() {
  echo "Resizing ip/$1.img"
  #mkdir ${workdir}/$1-keep
  #cp -ap --no-preserve=ownership ${workdir}/mount/. ${workdir}/$1-keep/
  sudo sync
  sudo umount ${workdir}/mount

  ofs=0
  sze=0
  while read n b e s t f z ; do
    ofs=`echo $b | tr -d B`
    sze=`echo $s | tr -d B`
  done <<< $(LANG=C $partedbin ${workdir}/$1.img unit b print 2>/dev/null | grep -m1 fat)

  if [ $1 = gaius ]; then
    echo ofs: $ofs sze: $sze

    # add 1% free space
    minFree=`expr ${maxSize} / 100`
    minSize=`expr $2 + ${minFree}`
    newSize=${minSize}

    # 16 MB steps
    newBls=`expr 16 '*' 1048576`
    newBlc=`expr ${newSize} / ${newBls}`
    newSize=`expr ${newBlc} '*' ${newBls}`
    if [ ${minSize} -gt ${newSize} ]; then
      newSize=`expr ${newSize} + ${newBls}`
    fi

    if [ ${newSize} -gt ${maxSize} ]; then
      newSize=${maxSize}
    fi

    #newSize=${maxSize}

    # 1073741823
    maxEnd=`expr ${newSize} - 1`
    # 1072693248
    maxSzl=`expr ${newSize} - ${ofs}`
    # 1024
    maxMBs=`expr ${newSize} / 1048576`

    echo "Resizing to ${maxMBs} MB, start ${ofs} byte, end ${maxEnd} byte, size ${maxSzl} byte"

    dd if=/dev/zero of=${workdir}/$1.img count=0 bs=1048576 seek=${maxMBs}

    LANG=C $partedbin ${workdir}/$1.img <<EOF
unit b
print
resize 1 ${ofs}B ${maxEnd}B
resizepart 1 ${maxEnd}B
print
quit
EOF

    LOOPDEV=`sudo losetup --find --show -o ${ofs} --sizelimit ${maxSzl} ${workdir}/$1.img`

    lbl=`sudo fatlabel $LOOPDEV | tail -1`
    uid=`sudo blkid $LOOPDEV -o export | grep -E '^UUID=' | cut -d '=' -f 2 | tr -d -`

    bootlabel=$lbl
    bootuuid=`sudo blkid $LOOPDEV -o export | grep -E '^UUID=' | cut -d '=' -f 2`

    echo ID: $uid label: $lbl

    zeroMBs=`expr ${maxSzl} / 1048576`
    zeroMBs=`expr ${zeroMBs} - 2`
    sudo dd if=/dev/zero of=$LOOPDEV count=${zeroMBs} bs=1048576 seek=2

    zeroMBs=`expr ${zeroMBs} + 2`
    zeroBs=`expr ${zeroMBs} '*' 1048576`
    if [ ${maxSzl} -gt ${zeroBs} ]; then
      sudo dd if=/dev/zero of=$LOOPDEV count=`expr ${maxSzl} - ${zeroBs}` bs=1 seek=${zeroBs}
    fi

    sudo mkfs.vfat -F 32 -h 2048 -i $uid -n $lbl $LOOPDEV

    sudo losetup -d $LOOPDEV

    ofs=0
    sze=0
    while read n b e s t f z ; do
      ofs=`echo $b | tr -d B`
      sze=`echo $s | tr -d B`
    done <<< $(LANG=C $partedbin ${workdir}/$1.img unit b print 2>/dev/null | grep -m1 fat)
  fi

  sudo mount -o loop,offset=$ofs,sizelimit=$sze ${workdir}/$1.img ${workdir}/mount

  #sudo cp -ap --no-preserve=ownership ${workdir}/$1-keep/. ${workdir}/mount/
}

shrinkimg() {
  cd ${scriptdir}/${workdir}/mount

  if [ $liveMode = winpe ]; then
    sudo rm sources/boot.wim
  fi

  cd ${scriptdir}

  liveSize=`du -d0 -B1 ${workdir}/gaius-add/ | cut -f 1`

  cd ${workdir}/mount/

  freeSize=`df -B1 --output=avail . | tail -1`
  freeSize=`expr ${freeSize} - 5000000`

  partSize=`df -B1 --output=size . | tail -1`

  usedSize=`df -B1 --output=used . | tail -1`
  needSize=`expr ${usedSize} + ${liveSize} + 5000000`

  echo ""
  df -B1 .
  echo ""

  if [ ${needSize} -gt ${maxSize} -a $liveMode != winpe ]; then
      echo "Deleting PE"
      sudo rm -f bootmgr
      sudo rm -f bootmgr.efi

      sudo rm -f boot/BCD
      sudo rm -f boot/bootfix.bin
      sudo rm -f boot/boot.sdi

      sudo rm -rf EFI/Microsoft/

      sudo rm -rf sources/
      sudo rm -rf win/
      sudo rm -rf winpe/

      freeSize=`df -B1 --output=avail . | tail -1`
      freeSize=`expr ${freeSize} - 5000000`

      usedSize=`df -B1 --output=used . | tail -1`
      needSize=`expr ${usedSize} + ${liveSize} + 5000000`

      df -B1 .
      echo ""
  fi

  if [ ${needSize} -gt ${maxSize} ]; then
      livedefault=true
      echo "Deleting IP"
      sudo rm boot/initrd.img
      sudo rm boot/vmlinuz
      sudo rm -rf hotfixes/
      sudo rm system/squashfs.img

      usedSize=`df -B1 --output=used . | tail -1`
      needSize=`expr ${usedSize} + ${liveSize} + 5000000`

      df -B1 .
      echo ""
  fi
}

copyimg()
{
  for f in ldlinux.sys bootmgr bootmgr.efi btmgr32 ; do
    if [ -e ${workdir}/$1/$f ]; then
      echo -n "$f "
      sudo cp -pu --no-preserve=ownership ${workdir}/$1/$f ${workdir}/mount/
    fi
  done

  for d in Boot boot EFI efi en-us ; do
    if [ -e ${workdir}/$1/$d ]; then
      echo -n "$d "
      sudo cp -apu --no-preserve=ownership ${workdir}/$1/$d ${workdir}/mount/
    fi
  done

  echo .

  sudo cp -apu --no-preserve=ownership ${workdir}/$1/. ${workdir}/mount/
}

cpdir() {
  if [ -e $1 ]; then
    cp -ap --no-preserve=ownership $1 $2
  fi
}

cpfile() {
  if [ -e $1 ]; then
    cp -p --no-preserve=ownership $1 $2
  fi
}

fixgrub() {
  if ! grep -q 'insmod jpeg' $1/grub.cfg ; then
    sed -i s/'^insmod font'/'insmod font\ninsmod jpeg'/g $1/grub.cfg
  fi
  if ! grep -q 'insmod png' $1/grub.cfg ; then
    sed -i s/'^insmod font'/'insmod font\ninsmod png'/g $1/grub.cfg
  fi
}

isofile=HPIP.iso
for f in `ls -tr HPIP*.iso IP*.iso 2>/dev/null` ; do
  isofile=$f
done

if [ ! -e ${isofile} ]; then
  isofile=HPIP170.2017_1006.67.iso
  # Gen8
  #wget -N https://downloads.hpe.com/pub/softlib2/software1/cd/p1450150448/v108035/HPIP163.2016_0720.i192.227.iso
  #wget -N https://downloads.hpe.com/pub/softlib2/software1/cd/p1450150448/v125952/HPIP164B.2017_0201.3.iso
  wget -N https://downloads.hpe.com/pub/softlib2/software1/cd/p1450150448/v126212/HPIP170.2017_1006.67.iso
  # Gen9
  #wget -N https://downloads.hpe.com/pub/softlib2/software1/cd/p1450150448/v119206/HPIP240B.2016_0514.6.iso
  #wget -N https://downloads.hpe.com/pub/softlib2/software1/cd/p1450150448/v109733/HPIP250.2016_1015.169.iso
  #wget -N https://downloads.hpe.com/pub/softlib2/software1/cd/p1450150448/v116505/HPIP260.2017_0505.157.iso
  #wget -N https://downloads.hpe.com/pub/softlib2/software1/cd/p1450150448/v128888/HPIP261.2017_0518.11.iso
  # Gen10
  #wget -N https://downloads.hpe.com/pub/softlib2/software1/cd/p1450150448/v105991/IP300.2017_0606.382.iso
fi

[ ! -e ${isofile} ] && exit 1

workdir=${isofile/.iso/}

if [ ! -e ${workdir} ]; then
  bash hpip-extract.sh
fi

partedbin=`sudo which parted`

mkisofso="-graft-points -U -J -joliet-long -r"
mkisobto="-no-emul-boot -boot-load-size 4 -boot-info-table"
mkisobin=`which mkisofs`
if [ X$mkisobin = X ]; then
  mkisobin=`which genisoimage`
fi
if [ X$mkisobin = X ]; then
  mkisobin=`which xorriso`
  if [ X$mkisobin != X ]; then
    mkisobin="$mkisobin -as mkisofs"
    mkisobto="$mkisobto --grub2-boot-info --protective-msdos-label --sort-weight 0 / --sort-weight 1 /boot"
  fi
fi

echo ""
echo Using ${workdir}


liveiso=Debian.iso
for f in `ls -tr *bian*.iso *buntu*.iso *admincd*.iso *arch*.iso *makeiso*.iso *CentOS*.iso *kali*.iso *Core*.iso *nano*.iso *slack*.iso *slax*.iso *tahr*.iso *Linux*.iso *live*.iso *Live*.iso *emergency*.iso *grml*.iso *magic*.iso *repair*.iso *rescue*.iso *thin*.iso *Thin*.iso *7pe*.iso *win*.iso *win*.ISO *7PE*.iso *Win*.iso *Win*.ISO *ccmulti*.iso 2>/dev/null` ; do
  liveiso=$f
done

if [ ! -e ${liveiso} ]; then
  liveiso=gparted-live-0.29.0-1-amd64.iso
  wget -N https://downloads.sourceforge.net/project/gparted/gparted-live-stable/0.29.0-1/gparted-live-0.29.0-1-amd64.iso
fi

[ ! -e ${liveiso} ] && exit 1

livedir=${liveiso}
livedir=${livedir/.iso/}
livedir=${livedir/.ISO/}
liveShort=`echo ${livedir} | sed s/'\.x86_64'/''/g | sed s/'-x86_64'/''/g | sed s/'[-_.][0-9_.-]*[-_]'/'-'/g | sed s/'[-_][0-9.-]*$'/''/g | sed s/'-64bit'/''/g | sed s/'-amd64+mac'/''/g | sed s/'-amd64'/''/g | sed s/'-x64'/''/g | sed s/'-x86'/''/g | sed s/'-uefi'/''/g | tr _ -`
liveName=`echo ${liveShort} | tr - ' '`
liveShort=`echo ${liveShort} | tr ' ' -`

liveLabel=`isoinfo -d -i ${liveiso} | grep -E '^Volume id:'      | cut -d : -f 2-`
liveSysid=`isoinfo -d -i ${liveiso} | grep -E '^System id:' | cut -d : -f 2-`
liveAppid=`isoinfo -d -i ${liveiso} | grep -E '^Application id:' | cut -d : -f 2-`

echo Using ${liveName} in ${livedir}
echo ISO label: ${liveLabel}

sudo mount -o loop,ro ${liveiso} ${workdir}/mount

mkdir -p ${workdir}/liveiso
cp -apP --no-preserve=ownership ${workdir}/mount/. ${workdir}/liveiso/
sudo chmod -R ugo+rw ${workdir}/liveiso/
sudo umount ${workdir}/mount

cd ${workdir}/liveiso/

liveMode=unknown
liveFDir=.
liveFS=filesystem.squashfs
loopMode=none

for f in `ls *-read-only.*-* 2>/dev/null` ; do
  liveMode=live
  liveFDir=`dirname $f`
  liveFS=`basename $f`
  mkdir -p ${liveMode}
done

for f in `ls *.squashfs 2>/dev/null` ; do
  liveMode=live
  liveFDir=`dirname $f`
  liveFS=`basename $f`
  mkdir -p ${liveMode}
done

for f in `ls puppy_*.sfs 2>/dev/null` ; do
  liveMode=puppy
  liveFDir=.
  liveFS=$f
  mkdir -p ${liveMode}
done

for f in `ls arch/*/*.sfs 2>/dev/null` ; do
  liveMode=arch
  liveFDir=`dirname $f`
  liveFS=`basename $f`
done

for f in `ls live/*/*.squashfs 2>/dev/null` ; do
  liveMode=live
  liveFDir=`dirname $f`
  liveFS=`basename $f`
done

for f in `ls pmagic/*/*.SQFS 2>/dev/null` ; do
  liveMode=pmagic
  liveFDir=`dirname $f`
  liveFS=`basename $f`
done

if [ -e casper/filesystem.squashfs ]; then
  liveMode=casper
  liveFDir=${liveMode}
  liveFS=filesystem.squashfs

elif [ -e live/filesystem.squashfs ]; then
  liveMode=live
  liveFDir=${liveMode}
  liveFS=filesystem.squashfs

elif [ -e LiveOS/squashfs.img ]; then
  liveMode=LiveOS
  liveFDir=${liveMode}
  liveFS=squashfs.img

elif [ -e images/install.img ]; then
  liveMode=images
  liveFDir=${liveMode}
  liveFS=install.img

elif [ -e pmagic/pmodules ]; then
  liveMode=pmagic

elif [ -e sysrcd.dat ]; then
  liveMode=sysrcd
  liveFDir=.
  liveFS=sysrcd.dat
  mkdir -p ${liveMode}

elif [ -e syslinux/alt0 -a -e rescue ]; then
  liveMode=alt0
  liveFDir=.
  liveFS=rescue
  mkdir -p ${liveMode}

elif [ -e livecd.loop ]; then
  liveMode=livecd
  liveFDir=.
  liveFS=livecd.loop
  mkdir -p ${liveMode}

elif [ -e cde ]; then
  liveMode=ucore
  mkdir -p ${liveMode}

elif [ -e KNOPPIX/KNOPPIX ]; then
  liveMode=KNOPPIX
  liveFDir=KNOPPIX
  liveFS=KNOPPIX

elif [ -e sources/boot.wim ]; then
  liveMode=winpe
  liveFDir=sources
  liveFS=boot.wim

elif [ -e sources/BOOT.WIM ]; then
  liveMode=winpe
  liveFDir=sources
  liveFS=BOOT.WIM

elif [ -e boot/image.md5 ]; then
  liveMode=tslive
  mkdir -p ${liveMode}

fi

if [ X${liveMode} = Xunknown ]; then
  echo "Unknown live ISO format"
  exit 1
fi

if [ -e ${liveFDir}/${liveFS} ]; then
  echo "Using fs ${liveFDir}/${liveFS}"
  file ${liveFDir}/${liveFS}
fi

if [ $liveMode = winpe ]; then
  liveInit=boot.sdi

  if [ -e boot/boot.sdi ]; then
    liveInit=boot/boot.sdi
  elif [ -e BOOT/BOOT.SDI ]; then
    liveInit=BOOT/BOOT.SDI
  fi

  liveKern=ntldr

  if [ -e bootmgr ]; then
    liveKern=bootmgr
  elif [ -e BOOTMGR ]; then
    liveKern=BOOTMGR
  fi

else
  liveIDir=${liveMode}
  liveInit=initrd

  for f in `ls arch/boot/*/arch*.i* 2>/dev/null` ; do
    liveIDir=`dirname $f`
    liveInit=`basename $f`
  done

  for f in `ls syslinux/*/full*.?z 2>/dev/null` ; do
    liveIDir=`dirname $f`
    liveInit=`basename $f`
  done

  for f in `ls syslinux/*/initrd* 2>/dev/null` ; do
    liveIDir=`dirname $f`
    liveInit=`basename $f`
  done

  for f in `ls isolinux/gentoo.i* 2>/dev/null` ; do
    liveIDir=`dirname $f`
    liveInit=`basename $f`
  done

  for f in `ls isolinux/initram* 2>/dev/null` ; do
    liveIDir=`dirname $f`
    liveInit=`basename $f`
  done

  for f in `ls isolinux/initrd* 2>/dev/null` ; do
    liveIDir=`dirname $f`
    liveInit=`basename $f`
  done

  for f in `ls boot/*/*/initrd* 2>/dev/null` ; do
    liveIDir=`dirname $f`
    liveInit=`basename $f`
  done

  for f in `ls boot/*/minirt* 2>/dev/null` ; do
    liveIDir=`dirname $f`
    liveInit=`basename $f`
  done

  for f in `ls boot/*/initrd* 2>/dev/null` ; do
    liveIDir=`dirname $f`
    liveInit=`basename $f`
  done

  for f in `ls boot/core*.?z 2>/dev/null` ; do
    liveIDir=`dirname $f`
    liveInit=`basename $f`
  done

  for f in `ls boot/initrd* 2>/dev/null` ; do
    liveIDir=`dirname $f`
    liveInit=`basename $f`
  done

  for f in `ls ./initrd* 2>/dev/null` ; do
    liveIDir=`dirname $f`
    liveInit=`basename $f`
  done

  if [ -e ${liveMode}/initrd.lz ]; then
    liveIDir=${liveMode}
    liveInit=initrd.lz
  elif [ -e ${liveMode}/initrd.gz ]; then
    liveIDir=${liveMode}
    liveInit=initrd.gz
  elif [ -e ${liveMode}/initrd.img ]; then
    liveIDir=${liveMode}
    liveInit=initrd.img
  elif [ -e ${liveMode}/minirt.gz ]; then
    liveIDir=${liveMode}
    liveInit=minirt.gz
  elif [ -e ${liveMode}/full.cz ]; then
    liveIDir=${liveMode}
    liveInit=full.cz
  fi

  if [ ${liveIDir} != ${liveMode} ]; then
    cp -p --no-preserve=ownership ${liveIDir}/${liveInit} ${liveMode}/
  fi

  if [ ! -e ${liveMode}/${liveInit} ]; then
    echo "Unknown live ISO format, initrd not found"
    exit 1
  fi

  echo Using init ${liveIDir}/${liveInit}

  liveKDir=${liveMode}
  liveKern=vmlinux

  for f in `ls arch/boot/*/vmlinu* 2>/dev/null` ; do
    liveKDir=`dirname $f`
    liveKern=`basename $f`
  done

  for f in `ls syslinux/*/vmlinu* 2>/dev/null` ; do
    liveKDir=`dirname $f`
    liveKern=`basename $f`
  done

  for f in `ls isolinux/rescue32* 2>/dev/null` ; do
    liveKDir=`dirname $f`
    liveKern=`basename $f`
  done

  for f in `ls isolinux/rescue64* 2>/dev/null` ; do
    liveKDir=`dirname $f`
    liveKern=`basename $f`
  done

  for f in `ls isolinux/gentoo 2>/dev/null` ; do
    liveKDir=`dirname $f`
    liveKern=`basename $f`
  done

  for f in `ls isolinux/vmlinu* 2>/dev/null` ; do
    liveKDir=`dirname $f`
    liveKern=`basename $f`
  done

  for f in `ls boot/*/*/linux 2>/dev/null` ; do
    liveKDir=`dirname $f`
    liveKern=`basename $f`
  done

  for f in `ls boot/*/*/vmlinu* 2>/dev/null` ; do
    liveKDir=`dirname $f`
    liveKern=`basename $f`
  done

  for f in `ls boot/*/linux 2>/dev/null` ; do
    liveKDir=`dirname $f`
    liveKern=`basename $f`
  done

  for f in `ls boot/*/gentoo 2>/dev/null` ; do
    liveKDir=`dirname $f`
    liveKern=`basename $f`
  done

  for f in `ls boot/*/bzImage* 2>/dev/null` ; do
    liveKDir=`dirname $f`
    liveKern=`basename $f`
  done

  for f in `ls boot/*/vmlinu* 2>/dev/null` ; do
    liveKDir=`dirname $f`
    liveKern=`basename $f`
  done

  for f in `ls boot/vmlinu* 2>/dev/null` ; do
    liveKDir=`dirname $f`
    liveKern=`basename $f`
  done

  for f in `ls ./vmlinu* 2>/dev/null` ; do
    liveKDir=`dirname $f`
    liveKern=`basename $f`
  done

  if [ -e ${liveMode}/vmlinuz ]; then
    liveKDir=${liveMode}
    liveKern=vmlinuz
  elif [ -e ${liveMode}/vmlinuz.efi ]; then
    liveKDir=${liveMode}
    liveKern=vmlinuz.efi
  elif [ -e ${liveMode}/bzImage64 ]; then
    liveKDir=${liveMode}
    liveKern=bzImage64
  elif [ -e ${liveMode}/bzImage ]; then
    liveKDir=${liveMode}
    liveKern=bzImage
  elif [ -e ${liveMode}/linux ]; then
    liveKDir=${liveMode}
    liveKern=linux
  fi

  if [ ${liveKDir} != ${liveMode} ]; then
    cp -p --no-preserve=ownership ${liveKDir}/${liveKern} ${liveMode}/
  fi

  if [ ! -e ${liveMode}/${liveKern} ]; then
    echo "Unknown live ISO format, kernel not found"
    exit 1
  fi

  echo Using kernel ${liveKDir}/${liveKern}
fi

cd ${scriptdir}

mountimg gaius

copyimg gaius

#cd ${scriptdir}/${workdir}/mount
cd ${scriptdir}/${workdir}/gaius

gaSysLdr=none
gaSysCDir=none
gaSysCfg=none.cfg

gaiusLdr=none
gaiusCDir=none
gaiusCfg=none.cfg
cfgtemplate=${scriptdir}/grub/grub.cfg

if [ -e boot/grub/grub.cfg ]; then
  gaiusLdr=grub
  gaiusCDir=boot/grub
  gaiusCfg=boot/grub/grub.cfg

  echo Found gaius/${gaiusCfg}

  if ! grep -q -E '^hpfirst' boot/grub/grub.cfg ; then
    if grep -q -E '^hpev CQTESS' boot/grub/grub.cfg ; then
      cfgtemplate=${cfgtemplate}-hpev
    fi
  fi
fi

if [ -e boot/syslinux/vesamenu.cfg ]; then
  gaSysLdr=syslinux
  gaSysCDir=boot/syslinux
  gaSysCfg=boot/syslinux/vesamenu.cfg

  echo Found gaius/${gaSysCfg}

  if [ -e ./back.jpg -a ! -e ./${gaSysCDir}/back.jpg ]; then
    mkdir -p ${scriptdir}/${workdir}/gaius-add/${gaSysCDir}
    sudo cp -p ./back.jpg ${scriptdir}/${workdir}/gaius-add/${gaSysCDir}/
  fi

  if [ $gaiusLdr = none ]; then
    gaiusLdr=${gaSysLdr}
    gaiusCDir=${gaSysCDir}
    gaiusCfg=${gaSysCfg}

    cfgtemplate=${scriptdir}/syslinux/vesamenu.cfg
  fi
fi

gaEfiLdr=none
gaEfiCDir=none
gaEfiCfg=none.cfg

if [ -e efi/boot/grub.cfg ]; then
  gaEfiLdr=grub
  gaEfiCDir=efi/boot
  gaEfiCfg=efi/boot/grub.cfg

  echo Found gaius/${gaEfiCfg}

  mkdir -p ${scriptdir}/${workdir}/gaius-add/${gaEfiCDir}

elif [ -e EFI/Boot/grub.cfg ]; then
  gaEfiLdr=grub
  gaEfiCDir=EFI/Boot
  gaEfiCfg=EFI/Boot/grub.cfg

  echo Found gaius/${gaEfiCfg}

  mkdir -p ${scriptdir}/${workdir}/gaius-add/${gaEfiCDir}
fi


mkdir -p ${scriptdir}/${workdir}/gaius-add/${gaiusCDir}
cp -p ./${gaiusCDir}/*.cfg ${scriptdir}/${workdir}/gaius-add/${gaiusCDir}/
cp -p ./${gaiusCfg}        ${scriptdir}/${workdir}/gaius-add/${gaiusCDir}/

cd ${scriptdir}/${workdir}/gaius-add

if [ ! -e ${cfgtemplate}-${liveMode} ]; then
  cp -p --no-preserve=ownership ${cfgtemplate}-live ./${gaiusCfg}
  sed -i "s|/live/vmlinuz|/${liveMode}/vmlinuz|g" ./${gaiusCfg}
  sed -i "s|/live/initrd|/${liveMode}/initrd|g" ./${gaiusCfg}
else
  cp -p --no-preserve=ownership ${cfgtemplate}-${liveMode} ./${gaiusCfg}
fi

if [ $gaiusLdr = grub ]; then
  fixgrub boot/grub
fi

cd ${scriptdir}/${workdir}/mount

livesrc=${scriptdir}/${workdir}/liveiso

if [ $liveMode = winpe ]; then
  #sudo rm sources/boot.wim

  cd ${scriptdir}/${workdir}/gaius-add

  mkdir -p ./sources


  cpdir ${livesrc}/Programs ./

  cp -p --no-preserve=ownership ${livesrc}/sources/boot.wim ./sources/

  cpfile ${livesrc}/*pe.cfg ./
  cpfile ${livesrc}/CdUsb.* ./
  cpfile ${livesrc}/pecmd*.ini ./
  cpfile ${livesrc}/Win*PE*.cd ./
  cpfile ${livesrc}/Win*SE*.cd ./

  if [ $gaiusLdr = grub ]; then
    sed -i "s|Windows PE|${liveName}|g" ./boot/grub/grub.cfg
  fi

else
  cd ${livesrc}

  if [ -e ${liveMode}/${liveInit} ]; then
    echo "Extracting ${liveMode}/${liveInit}"
    file ${liveMode}/${liveInit}

    cd ${scriptdir}

    mkdir -p ${workdir}/live-initrd
    cd ${workdir}/live-initrd/

    if file ${livesrc}/${liveMode}/${liveInit} | grep -q Squashfs ; then
      true
    elif file ${livesrc}/${liveMode}/${liveInit} | grep -q gzip ; then
      cat ${livesrc}/${liveMode}/${liveInit} | gzip -dc > ../live-initrd.img
    elif file ${livesrc}/${liveMode}/${liveInit} | grep -q bzip2 ; then
      cat ${livesrc}/${liveMode}/${liveInit} | bzip2 -dc > ../live-initrd.img
    elif file ${livesrc}/${liveMode}/${liveInit} | grep -q LZMA ; then
      cat ${livesrc}/${liveMode}/${liveInit} | lzma -dc > ../live-initrd.img
    elif file ${livesrc}/${liveMode}/${liveInit} | grep -q XZ ; then
      cat ${livesrc}/${liveMode}/${liveInit} | xz -dc > ../live-initrd.img
    else
      cat ${livesrc}/${liveMode}/${liveInit} > ../live-initrd.img
    fi

    if [ -e ../live-initrd.img ]; then
      if file ../live-initrd.img | grep -q cpio ; then
        cat ../live-initrd.img | cpio -id
      fi
    fi

    cd ${livesrc}
  fi

  lxcmdline="boot=${liveMode}"

  tempLdr=none
  tempDir=boot
  tempCfg=grub.cfg

  if [ -e boot/grub/loopback.cfg ]; then
    tempLdr=grub
    tempDir=boot/grub
    tempCfg=boot/grub/loopback.cfg
  fi
  if [ -e boot/grub/grub.cfg     ]; then
    tempLdr=grub
    tempDir=boot/grub
    tempCfg=boot/grub/grub.cfg
  fi

  if [ $tempLdr = grub -a -e ${tempCfg} ]; then
    if [ ${liveKDir} != ${liveMode} ]; then
      lxcmdtemp=`cat ${tempCfg} | sed s/'^[ \t]*linux'/'linux'/g | grep -m1 -E 'linux.*'/${liveKDir}/${liveKern} | sed "s|${liveKDir}/${liveKern}|${liveMode}/${liveKern}|g"`
    else
      lxcmdtemp=`cat ${tempCfg} | sed s/'^[ \t]*linux'/'linux'/g | grep -m1 -E 'linux.*'/${liveKDir}/${liveKern}`
    fi

    if echo X${lxcmdtemp} | grep -q -m1 -E 'linux.*'/${liveMode}/${liveKern} ; then
      liveLdr=${tempLdr}
      liveCfg=${tempCfg}
      lxcmdline=$lxcmdtemp
    fi
  fi

  tempLdr=none
  tempCfg=isolinux.cfg

  for f in `ls boot/*/*/isolinux.cfg 2>/dev/null` ; do
    tempLdr=syslinux
    tempDir=`dirname $f`
    tempCfg=$f
    echo Found $tempCfg
  done

  if [ -e boot/syslinux/syslinux.cfg ]; then
    tempLdr=syslinux
    tempDir=boot/syslinux
    tempCfg=boot/syslinux/syslinux.cfg
    echo Found $tempCfg
  fi
  if [ -e boot/syslinux/isolinux.cfg ]; then
    tempLdr=syslinux
    tempDir=boot/syslinux
    tempCfg=boot/syslinux/isolinux.cfg
    echo Found $tempCfg
  fi
  if [ -e boot/isolinux/isolinux.cfg ]; then
    tempLdr=syslinux
    tempDir=boot/isolinux
    tempCfg=boot/isolinux/isolinux.cfg
    echo Found $tempCfg
  fi
  if [ -e boot/isolinux/default.cfg ]; then
    tempLdr=syslinux
    tempDir=boot/isolinux
    tempCfg=boot/isolinux/default.cfg
    echo Found $tempCfg
  fi
  if [ -e syslinux/isolinux.cfg ]; then
    tempLdr=syslinux
    tempDir=syslinux
    tempCfg=syslinux/isolinux.cfg
    echo Found $tempCfg
  fi
  if [ -e isolinux/isolinux.cfg ]; then
    tempLdr=syslinux
    tempDir=isolinux
    tempCfg=isolinux/isolinux.cfg
    echo Found $tempCfg
  fi
  if [ -e isolinux/txt.cfg ]; then
    tempLdr=syslinux
    tempDir=isolinux
    tempCfg=isolinux/txt.cfg
    echo Found $tempCfg
  fi
  if [ -e ./isolinux.cfg ]; then
    tempLdr=syslinux
    tempDir=.
    tempCfg=./isolinux.cfg
    echo Found $tempCfg
  fi
  if [ -e arch/boot/syslinux/syslinux.cfg ]; then
    tempLdr=syslinux
    tempDir=arch
    tempCfg=arch/boot/syslinux/syslinux.cfg
    echo Found $tempCfg
  fi
  if [ -e arch/boot/syslinux/archiso_sys.cfg ]; then
    tempLdr=syslinux
    tempDir=arch
    tempCfg=arch/boot/syslinux/archiso_sys.cfg
    echo Found $tempCfg
  fi
  if [ -e arch/boot/syslinux/archiso_sys64.cfg ]; then
    tempLdr=syslinux
    tempDir=arch
    tempCfg=arch/boot/syslinux/archiso_sys64.cfg
    echo Found $tempCfg
  fi

  if [ $tempLdr = syslinux -a -e ${tempCfg} ]; then
    echo Using $tempCfg
    trekDir=`echo ${liveKDir}/ | sed "s|^${tempDir}/||g"`
    trelDir=`echo ${liveIDir}/ | sed "s|^${tempDir}/||g"`
    tGotCmd=false

    if [ ${liveKDir} != ${liveMode} ]; then
      lxcmdtemp=`cat ${tempCfg} | grep -v '#append' | grep -m1 -E 'append.*initrd=.*'${trelDir}${liveInit} | sed "s|${liveKDir}/${liveKern}|${liveMode}/${liveKern}|g"`
    else
      lxcmdtemp=`cat ${tempCfg} | grep -v '#append' | grep -m1 -E 'append.*initrd=.*'${trelDir}${liveInit}`
    fi

    if echo X${lxcmdtemp} | grep -q -m1 -E 'append.*initrd=.*'${trelDir}${liveInit} ; then
      tGotCmd=true
      liveLdr=${tempLdr}
      liveCfg=${tempCfg}
      lxcmdline=`echo $lxcmdtemp | sed s/'.*append'/''/g | sed 's|initrd='/${liveIDir}/${liveInit}'||g' | sed 's|initrd='${trelDir}${liveInit}'||g'`
    fi

    if [ $tGotCmd = false ] ; then
      if [ ${liveKDir} != ${liveMode} ]; then
        lxcmdtemp=`cat ${tempCfg} | grep -m1 -A1 -E 'INITRD.*'${trelDir}${liveInit} | grep -v '#APPEND' | grep APPEND | sed "s|${liveKDir}/${liveKern}|${liveMode}/${liveKern}|g"`
      else
        lxcmdtemp=`cat ${tempCfg} | grep -m1 -A1 -E 'INITRD.*'${trelDir}${liveInit} | grep -v '#APPEND' | grep APPEND`
      fi

      if echo X${lxcmdtemp} | grep -q APPEND ; then
        tGotCmd=true
        liveLdr=${tempLdr}
        liveCfg=${tempCfg}
        lxcmdline=`echo $lxcmdtemp | sed s/'.*APPEND'/''/g`
      fi
    fi

    if [ $tGotCmd = false ] ; then
      if [ ${liveKDir} != ${liveMode} ]; then
        lxcmdtemp=`cat ${tempCfg} | grep -m1 -A1 -E 'initrd.*'${trelDir}${liveInit} | grep -v '#append' | grep append | sed "s|${liveKDir}/${liveKern}|${liveMode}/${liveKern}|g"`
      else
        lxcmdtemp=`cat ${tempCfg} | grep -m1 -A1 -E 'initrd.*'${trelDir}${liveInit} | grep -v '#append' | grep append`
      fi

      if echo X${lxcmdtemp} | grep -q append ; then
        tGotCmd=true
        liveLdr=${tempLdr}
        liveCfg=${tempCfg}
        lxcmdline=`echo $lxcmdtemp | sed s/'.*append'/''/g`
      fi
    fi

    if [ $tGotCmd = false ] ; then
      if [ ${liveKDir} != ${liveMode} ]; then
        lxcmdtemp=`cat ${tempCfg} | grep -A2 -E 'KERNEL.*'${trekDir}${liveKern}'|LINUX.*'${trekDir}${liveKern} | grep -v '#APPEND' | grep -m1 -B2 APPEND | grep APPEND | sed "s|${liveKDir}/${liveKern}|${liveMode}/${liveKern}|g"`
      else
        lxcmdtemp=`cat ${tempCfg} | grep -A2 -E 'KERNEL.*'${trekDir}${liveKern}'|LINUX.*'${trekDir}${liveKern} | grep -v '#APPEND' | grep -m1 -B2 APPEND | grep APPEND`
      fi

      if echo X${lxcmdtemp} | grep -q APPEND ; then
        tGotCmd=true
        liveLdr=${tempLdr}
        liveCfg=${tempCfg}
        lxcmdline=`echo $lxcmdtemp | sed s/'.*APPEND'/''/g`
      fi
    fi

    if [ $tGotCmd = false ] ; then
      if [ ${liveKDir} != ${liveMode} ]; then
        lxcmdtemp=`cat ${tempCfg} | grep -A2 -E 'kernel.*'${trekDir}${liveKern}'|linux.*'${trekDir}${liveKern} | grep -v '#append' | grep -m1 -B2 append | grep append | sed "s|${liveKDir}/${liveKern}|${liveMode}/${liveKern}|g"`
      else
        lxcmdtemp=`cat ${tempCfg} | grep -A2 -E 'kernel.*'${trekDir}${liveKern}'|linux.*'${trekDir}${liveKern} | grep -v '#append' | grep -m1 -B2 append | grep append`
      fi

      if echo X${lxcmdtemp} | grep -q append ; then
        tGotCmd=true
        liveLdr=${tempLdr}
        liveCfg=${tempCfg}
        lxcmdline=`echo $lxcmdtemp | sed s/'.*append'/''/g`
      fi
    fi

    if [ $tGotCmd = true -a $liveMode = puppy ]; then
      if ! echo "X ${lxcmdline}" | grep -q ' pmedia=' ; then
        lxcmdline="${lxcmdline} pmedia=cd"
      fi

      lxcmdline=${lxcmdline/pfix=ram,/pfix=}
      lxcmdline=${lxcmdline/pfix=ram/}
    fi


    if [ $tGotCmd = true ]; then
      if ! echo "X ${lxcmdline}" | grep -q ' noprompt' ; then
        lxcmdline=${lxcmdline/boot=${liveMode} /boot=${liveMode} noprompt }
      fi

      if [ -e glump ]; then
        loopMode=iso
        #LABEL=${bootlabel}
        fixedlabel=`echo ${bootlabel} | sed "s/ *$//g"`
        loopRoot=/dev/disk/by-label/${fixedlabel}
        #loopISO=/glump
        loopISO=/${liveMode}/loop.iso
        lxcmdline=${lxcmdline}' isofrom='${loopRoot}':'${loopISO}' isofrom_device='${loopRoot}' isofrom_system='${loopISO}
      fi

      if [ $gaiusLdr = grub ]; then
        lxcmdline='linux	'/${liveMode}/${liveKern}'  '${lxcmdline}
      else
        if ! echo ${lxcmdline} | grep -q 'vga=' ; then
          lxcmdline='vga=794 '${lxcmdline}
        fi
        lxcmdline='append  initrd='/${liveMode}/${liveInit}'  '${lxcmdline}
      fi
    fi

  fi


  cd ${scriptdir}/${workdir}/gaius-add

  if [ $gaiusLdr = grub ]; then
    sed -i 's|'${liveMode}/initrd.lz'|'${liveMode}/${liveInit}'|g' ./boot/grub/grub.cfg
  fi

  cpdir ${livesrc}/.disk ./
  cpdir ${livesrc}/conf ./
  cpdir ${livesrc}/dists ./
  cpdir ${livesrc}/install ./
  cpdir ${livesrc}/pool ./
  cpdir ${livesrc}/preseed ./

  cpdir ${livesrc}/cde ./

  cpdir ${livesrc}/Packages ./

  cp -ap --no-preserve=ownership ${livesrc}/${liveMode} ./

  echo $lxcmdline
  if echo $lxcmdline | grep -q -E "${liveKern}|${liveInit}" ; then
    lxcmdtoram=`echo ${lxcmdline} | sed s/'boot='${liveMode}' '/'boot='${liveMode}' toram '/g | sed s/'archisobasedir='${liveMode}' '/'archisobasedir='${liveMode}' copytoram=y '/g`

    echo $lxcmdtoram
    echo got cmdline from ${liveCfg}

    if [ $gaiusLdr = grub ]; then
      #sed -i 's|linux.*'/${liveMode}/vmlinuz'.*|'${lxcmdline}'|g' ./boot/grub/grub.cfg
      sed -i "s|linux.*/${liveMode}/vmlinuz.*toram.*|xXlinux-cmdline-toram-hereXx|g" ./boot/grub/grub.cfg
      sed -i "s|linux.*/${liveMode}/vmlinuz.*|${lxcmdline}|g" ./boot/grub/grub.cfg
      sed -i "s|xXlinux-cmdline-toram-hereXx|${lxcmdtoram}|g" ./boot/grub/grub.cfg

    elif [ $gaiusLdr = syslinux ]; then
      sed -i "s|append.*/${liveMode}/initrd.lz.*toram.*|xXlinux-cmdline-toram-hereXx|g" ./${gaiusCfg}
      sed -i "s|append.*/${liveMode}/initrd.lz.*|${lxcmdline}|g" ./${gaiusCfg}
      sed -i "s|xXlinux-cmdline-toram-hereXx|${lxcmdtoram}|g" ./${gaiusCfg}

      sed -i "s|/${liveMode}/vmlinuz|/${liveMode}/${liveKern}|g" ./${gaiusCfg}
    fi

    sed -i "s/automatic=method:cdrom /automatic=method:disk,uuid:${bootuuid} /g" ./${gaiusCfg}
    if [ "X${liveLabel}" != "X" ]; then
      sed -i "s|archisolabel=${liveLabel}|archisolabel=${bootlabel}|g" ./${gaiusCfg}
      sed -i "s|inst.stage2=hd:LABEL=${liveLabel}|inst.stage2=hd:LABEL=${bootlabel}|g" ./${gaiusCfg}

      fixedlabel=`echo ${liveLabel} | sed s/' '/'\\\\x20'/g`
      if [ "X${fixedlabel}" != "X${liveLabel}" ]; then
        sed -i "s|archisolabel=${fixedlabel}|archisolabel=${bootlabel}|g" ./${gaiusCfg}
        sed -i "s|inst.stage2=hd:LABEL=${fixedlabel}|inst.stage2=hd:LABEL=${bootlabel}|g" ./${gaiusCfg}
      fi
    else
      sed -i "s|archisolabel=ARCH_[0-9]*|archisolabel=${bootlabel}|g" ./${gaiusCfg}
    fi

  else
    if [ ! -e ./${liveMode}/vmlinuz ]; then
      #cp -p ./${liveKDir}/${liveKern} ./${liveMode}/vmlinuz
      sed -i "s|/${liveMode}/vmlinuz|/${liveMode}/${liveKern}|g" ./${gaiusCfg}
    fi
  fi

  sed -i "s|Debian-XFCE|${liveName}|g" ./${gaiusCfg}
  sed -i "s|Xubuntu|${liveName}|g" ./${gaiusCfg}

  if [ $gaiusLdr = grub ]; then
    if [ $livedefault = true ]; then
      sed -i "s|set default=0|set default=2|g" ./boot/grub/grub.cfg
    fi
  fi

  if [ $gaiusLdr = grub -a $gaEfiLdr = grub ]; then
    cat <<EOFGEFICFG | tee ./${gaEfiCfg} > /dev/null
insmod efi_gop
insmod efi_uga
EOFGEFICFG

    cat ./${gaiusCfg} >> ./${gaEfiCfg}

    if [ -e ${scriptdir}/${workdir}/mount/EFI/Microsoft/Boot/bootx64.efi -o \
         -e ${scriptdir}/${workdir}/mount/efi/microsoft/boot/bootx64.efi ]; then
      sed -i "s|insmod part_msdos|insmod part_gpt|g" ./${gaEfiCfg}
      sed -i "s|insmod ntldr|insmod chain|g" ./${gaEfiCfg}
      sed -i "s|ntldr /bootmgr|chainloader /efi/microsoft/boot/bootx64.efi|g" ./${gaEfiCfg}
    fi
  fi

  if [ $gaiusLdr = syslinux ]; then
    #sed -i s/'^DEFAULT hpfirst'/'include vesamenu.cfg\ndefault vesamenu.c32\n#DEFAULT hpfirst'/g ./${gaiusCDir}/syslinux.cfg
    sed -i s/'^#HP VESA vesamenu'/'HP VESA vesamenu'/g ./${gaiusCDir}/syslinux.cfg
    sed -i s/'^HP VESA gfxboot'/'#HP VESA gfxboot'/g ./${gaiusCDir}/syslinux.cfg

    sed -i s/'^MENU HIDDEN'/'#MENU HIDDEN'/g ./${gaiusCfg}
    sed -i s/'^TIMEOUT .*'/'TIMEOUT 150'/g ./${gaiusCfg}

    # switch from 1280x1024x24 to 1280x1024x16
    sed -i s/'vga=0x31b'/'vga=794'/g ./${gaiusCfg}
    sed -i s/'vga=0x31B'/'vga=794'/g ./${gaiusCfg}
    sed -i s/'vga=795'/'vga=794'/g ./${gaiusCfg}

    cat ./${gaiusCfg} | sed s/'^UI vesamenu.c32'/'UI menu.c32'/g | \
      sed /'^MENU COLOR'/d | \
      sed /'^MENU BACKGROUND'/d | \
      sed /'^MENU RESOLUTION'/d | \
      sed /'^MENU TABMSG'/d | \
      sed /'^MENU LOADMSG'/d | \
      sed /'^MENU AUTOBOOT'/d | \
      sed /'^MENU WIDTH'/d | \
      sed /'^MENU MARGIN'/d | \
      sed /'^MENU ROWS'/d | \
      sed /'^MENU TABMSGROW'/d | \
      sed /'^MENU LOADMSGROW'/d | \
      sed /'^MENU CMDLINEROW'/d | \
      sed /'^MENU ENDROW'/d | \
      sed /'^MENU TIMEOUTROW'/d | \
      sed /'^MENU HSHIFT'/d | \
      sed /'^MENU VSHIFT'/d > ./${gaiusCDir}/menu.cfg

    cat ./${gaiusCDir}/menu.cfg | sed s/'^UI menu.c32'/'UI gfxboot.c32'/g > ./${gaiusCDir}/gfxmenu.cfg
  fi

  cpfile ${livesrc}/${liveFS} ./
  cpfile ${livesrc}/zdrv_*.sfs ./

  cpfile ${livesrc}/md5sum.txt ./
  cpfile ${livesrc}/README.diskdefines ./
  cpfile ${livesrc}/ubuntu ./

  cpfile ${livesrc}/config.isoclient ./
  cpfile ${livesrc}/glump ./
  cpfile ${livesrc}/*-Live-* ./
  cpfile ${livesrc}/GPL* ./
  cpfile ${livesrc}/liveboot ./
  cpfile ${livesrc}/livecd ./

  mkdir ./livedebs
  cp -p --no-preserve=ownership ${scriptdir}/${workdir}/hp*-deb/hp*.deb ./livedebs/

  if [ $loopMode = iso ]; then
    mkdir ../loopiso
    mv config.isoclient ../loopiso/
    mv glump ../loopiso/
    mv liveboot ../loopiso/
    mv ${liveFS} ../loopiso/

    cd ../loopiso
    $mkisobin $mkisofso -volid "${liveLabel}" -sysid "${liveSysid}" -appid "${liveAppid}" -o ../loop.iso .
    cd - > /dev/null
    mv ../loop.iso ${liveMode}/
  fi

fi

shrinkimg

cd ${scriptdir}

echo "Needing ${needSize} bytes"
if [ ${needSize} -gt $partSize ]; then
  resizeimg gaius ${needSize}
  sudo sync
  cd ${scriptdir}

  copyimg gaius
  sudo sync

  shrinkimg
  sudo sync
  cd ${scriptdir}
fi

echo "Adding ${liveSize} bytes"
sudo cp -ap --no-preserve=ownership ${workdir}/gaius-add/. ${workdir}/mount/

cd ${workdir}/mount/

df -B1 .

cd ${scriptdir}

echo ""
echo "You can make your own changes in ${workdir}/mount now, if required."
echo "Press Enter when done."
read f;

sudo sync
sudo umount ${workdir}/mount

mkdir -p ${workdir}/combinediso
cp -apP ${workdir}/iso/. ${workdir}/combinediso/
sudo sync

echo "Creating ip/gaius.img.gz"
cat ${workdir}/gaius.img | gzip -c > ${workdir}/combinediso/ip/gaius.img.gz
sudo sync

for f in `ls ${workdir}/combinediso/ip/*-*.rpm 2>/dev/null` ; do
  r=`basename $f`
  n=`echo $r | sed s/'-[0-9].*'/''/g`

  if [ -e ${workdir}/combinediso/ip/${n}.img.gz -o -e ${workdir}/gaius-${n} ]; then
    echo Deleting ip/${r}
    rm ${workdir}/combinediso/ip/${r}
  fi
done

cd ${workdir}/combinediso/ip/

sudo rm md5s.txt
sudo rm sha1sums.txt
md5sum *.img.gz > md5s.txt
shasum *.img.gz > sha1sums.txt

cd ${scriptdir}

IMAGE=`basename ${isofile} | cut -d _ -f 1 | cut -d . -f 1`-${liveShort}.iso
IMAGE_NAME=`basename ${isofile} | cut -d _ -f 1 | cut -d . -f 1`
IMAGE_BOOT=boot/grub/i386-pc/eltorito.img

cd ${workdir}/combinediso/

if [ -e boot/grub ]; then
  fixgrub boot/grub
fi

if [ $gaiusLdr = syslinux -a -e system/isolinux.bin -a ! -e ${IMAGE_BOOT} ]; then
  IMAGE_BOOT=system/isolinux.bin

  sed -i s/'^ui gfxboot.*'/'ui vesamenu.c32'/g system/isolinux.cfg

  if grep -q -E 'vesamenu.c32' system/isolinux.cfg ; then
    if ! grep -q -E '^MENU COLOR' system/isolinux.cfg ; then
      cat <<EOFBOOTCFG | tee -a system/isolinux.cfg > /dev/null
MENU BACKGROUND back.jpg
MENU RESOLUTION 1024 768

MENU TITLE Intelligent Provisioning

MENU COLOR sel     7;37;44 #ff0030a5 #ff94c3f7 none
MENU COLOR unsel   34;47   #ff0030a5 #ffffffff none
MENU COLOR border  37;47   #ffd3d6e7 #ffd3d6e7 none
MENU COLOR title   37;47   #ff0030a5 #ffd3d6e7 none
#MENU COLOR timeout 1;37;44 #ffffffff #00000000 none

MENU TABMSG
MENU LOADMSG Booting
MENU AUTOBOOT #
MENU WIDTH 76

MENU MARGIN 2
MENU ROWS 16
MENU TABMSGROW 64
MENU LOADMSGROW 25
MENU CMDLINEROW  66
MENU ENDROW -1
MENU TIMEOUTROW 30
MENU HSHIFT 25
MENU VSHIFT 12
EOFBOOTCFG
    fi
  fi
fi

if [ -e ${IMAGE_BOOT} ]; then
  if [ -e efi/boot/efi.img ] ;then
    mkisobto="$mkisobto -eltorito-alt-boot -e efi/boot/efi.img -no-emul-boot"
  fi

  echo $mkisobin $mkisofso -appid "" -sysid "" -volid "$IMAGE_NAME" \
            -b ${IMAGE_BOOT} -c boot.catalog $mkisobto \
            -o ../${IMAGE} .

  $mkisobin $mkisofso -appid "" -sysid "" -volid "$IMAGE_NAME" \
            -b ${IMAGE_BOOT} -c boot.catalog $mkisobto \
            -o ../${IMAGE} .
  #--modification-date=2017100821273500 \
  #--grub2-mbr /usr/lib/grub/i386-pc/boot_hybrid.img

else
  if [ ! -e boot/grub/grub.cfg ]; then
    if [ -e efi/boot/grub.cfg ]; then
      mkdir -p boot/grub
      cp -p efi/boot/grub.cfg boot/grub/

      fixgrub boot/grub
    fi
  fi

  LANG=C grub-mkrescue -o ../${IMAGE} . -- -volid "$IMAGE_NAME"
fi

sudo sync
